pub fn decode_commit_log(
data: &[u8],
) -> Result<PlaintextCommitLogEntry, DecodeError>Expand description
Decode a commit-log entry without checking its signature or hash chain.
pub fn decode_commit_log(
data: &[u8],
) -> Result<PlaintextCommitLogEntry, DecodeError>Decode a commit-log entry without checking its signature or hash chain.