pub enum TlsSetMutation<K> {
Insert(K),
Remove(K),
RemoveByHash(TlsKeyHash),
}Expand description
A mutation to apply to a TlsSet.
Wire format: u8(tag) || payload where:
- tag 0 = Insert:
K(tls) - tag 1 = Remove:
K(tls) - tag 2 = RemoveByHash:
[u8; 32](SHA-256 of the key’s TLS serialization)
Variants
Insert(K)
Insert a key. Fails if the key already exists.
Remove(K)
Remove a key by value. Fails if the key doesn’t exist.
RemoveByHash(TlsKeyHash)
Remove a key by the SHA-256 hash of its TLS serialization. Avoids sending large keys over the wire for removal. Fails if no key with a matching hash exists.