pub fn find_mutable_metadata_extension(
extensions: &Extensions<GroupContext>,
) -> Option<&Vec<u8>>Expand description
Finds the mutable metadata extension in the given MLS Extensions.
This function searches for an Unknown Extension with the MUTABLE_METADATA_EXTENSION_ID.